@@ -4,14 +4,16 @@
 # Pod stripped from pm file by OODoc 2.01.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 
 use warnings;
 use strict;
 
 use Dancer2::Plugin;
-use Log::Report  'log-report', syntax => 'REPORT';
+use Dancer2::Plugin::LogReport::Message;
+use Log::Report  'log-report', syntax => 'REPORT',
+    message_class => 'Dancer2::Plugin::LogReport::Message';
 
 use Scalar::Util qw/blessed/;
 
@@ -25,6 +27,11 @@ sub import
     Log::Report->import('+2', @_, syntax => 'LONG');
 }
 
+my %session_messages;
+# The default reasons that a message will be displayed to the end user
+my @default_reasons = qw/NOTICE WARNING MISTAKE ERROR FAULT ALERT FAILURE PANIC/;
+my $hide_real_message; # Used to hide the real message to the end user
+
 # Dancer2 import
 on_plugin_import
 {   my $dsl      = $_dsl      = shift;  # capture global singleton
@@ -46,18 +53,35 @@ on_plugin_import
     {   # Need after_error for HTTP errors (eg 404) so as to
         # be able to change the forwarding location
         $dsl->hook(after_error => sub {
-            use Data::Dumper; say STDERR Dumper \@_;
             my $error = shift;
-            my $msg = $error->status . ": "
-              . Dancer2::Core::HTTP->status_message($error->status);
+            my $msg = __($error->status . ": "
+              . Dancer2::Core::HTTP->status_message($error->status));
 
-            # XXX How to write messages to the session? request() is not
-            # in the DSL at this point. At least log it.
-            report 'TRACE' => $msg;
-            _forward_home( $error, danger => $msg ); # $error is the request
+            # XXX This doesn't work at the moment. The DSL at this point
+            # doesn't seem to respond to changes in the session or
+            # forward requests
+            _forward_home( $_dsl, $msg );
         });
     }
 
+    # Define which messages are saved to the session for later display
+    # to the user. This can be configured in the config file, or we
+    # choose some sensible defaults.
+    my $sm = $settings->{session_messages} // \@default_reasons;
+    $session_messages{$_} = 1
+        for ref $sm eq 'ARRAY' ? @$sm : $sm;
+
+    # In a production server, we don't want the end user seeing (unexpected)
+    # exception messages, for both security and usability. If we detect
+    # that this is a production server (show_errors is 0), then we change
+    # the specific error to a generic error, when displayed to the user.
+    # The message can be customised in the config file.
+    my $fatal_error_message = $settings->{fatal_error_message}
+        || "An unexpected error has occurred";
+    unless($dsl->app->config->{show_errors})
+    {   $hide_real_message->{$_} = $fatal_error_message for qw/FAULT ALERT FAILURE PANIC/;
+    }
+
     # This is so that all messages go into the session, to be displayed
     # on the web page (if required)
     dispatcher CALLBACK => 'error_handler'
@@ -81,27 +105,34 @@ sub process($$)
 
 register process => \&process;
 
-sub _message_add($$)
-{   my ($type, $text) = @_;
-    $text && $type or return;
+sub _message_add($)
+{   my $msg = shift;
+    return unless $session_messages{$msg->reason};
     unless ($_dsl->app->request)
     {   # This happens for HTTP errors
         # XXX the session is not available in the DSL
         report 'ASSERT' => "Unable to write message to session: unable to write cookie";
         return;
     }
+
+    my $r = $msg->reason;
+    if(my $newm = $hide_real_message->{$r})
+    {   $msg = __$newm;
+        $msg->reason($r);
+    }
+
     my $messages_variable = $_settings->{messages_key} || 'messages';
     my $session           = $_dsl->app->session;
     my $msgs              = $session->read($messages_variable);
-    push @$msgs, { text => $text, type => $type };
+    push @$msgs, $msg;
     $session->write($messages_variable => $msgs);
 }
 
 #------
 
-sub _forward_home($$$)
+sub _forward_home($$)
 {   my $dsl = shift;
-    _message_add(shift, shift);
+    _message_add(shift);
     my $page = $_settings->{forward_url} || '/';
     $dsl->redirect($page);
 }
@@ -110,22 +141,15 @@ sub _error_handler($$$$)
 {   my ($disp, $options, $reason, $message) = @_;
 
     my $fatal_handler = sub {
-        _forward_home( $_dsl, danger => $_[0] )
+        _forward_home( $_dsl, $_[0] )
             unless $_dsl->request->uri eq '/' && $_dsl->request->is_get;
     };
 
+    $message->reason($reason);
+
     my %handler =
       ( # Default do nothing for the moment (TRACE|ASSERT|INFO)
-        default => sub {}
-
-        # Notice that something has happened. Not an error.
-      , NOTICE  => sub {_message_add info => $_[0]}
-
-        # Non-fatal problem. Show warning.
-      , WARNING => sub {_message_add warning => $_[0]}
-
-        # Non-fatal problem. Show warning.
-      , MISTAKE => sub {_message_add warning => $_[0]}
+        default => sub {_message_add $_[0]}
 
         # A user-created error condition that is not recoverable.
         # This could have already been caught by the process
@@ -134,10 +158,10 @@ sub _error_handler($$$$)
         # out. With the former, the exception will have been
         # re-thrown as a non-fatal exception, so check that.
       , ERROR   => sub {
-            return _message_add( danger => $_[0] )
+            return _message_add( $_[0] )
                 if exists $options->{is_fatal} && !$options->{is_fatal};
 
-            return  _forward_home( $_dsl, danger => $_[0] )
+            return  _forward_home( $_dsl, $_[0] )
                 if $_dsl->request->uri ne '/' || !$_dsl->request->is_get;
 
             return;
@@ -155,15 +179,22 @@ sub _error_handler($$$$)
       );
 
     my $call = $handler{$reason} || $handler{default};
-    $call->("$message");
+    $call->($message);
 }
 
 sub _report($@) {
     my ($reason, $dsl) = (shift, shift);
 
+
     my $msg = (blessed($_[0]) && $_[0]->isa('Log::Report::Message'))
        ? $_[0] : Dancer2::Core::Role::Logger::_serialize(@_);
 
+    if ($reason eq 'SUCCESS')
+    {
+        $msg = __$msg unless blessed $msg;
+        $msg = $msg->clone(_class => 'success');
+        $reason = 'NOTICE';
+    }
     report uc($reason) => $msg;
 }
 
@@ -173,10 +204,12 @@ register notice  => sub { _report(NOTICE => @_) };
 register mistake => sub { _report(MISTAKE => @_) };
 register panic   => sub { _report(PANIC => @_) };
 register alert   => sub { _report(ALERT => @_) };
+register success => sub { _report(SUCCESS => @_) };
 
 register_plugin for_versions => ['2'];
 
 #----------
 
+
 1;
 
