@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 use base 'Exporter';
 
@@ -16,6 +16,7 @@ use List::Util         qw/first/;
 use Scalar::Util       qw/blessed/;
 
 use Log::Report::Util;
+my $lrm = 'Log::Report::Message';
 
 ### if you change anything here, you also have to change Log::Report::Minimal
 my @make_msg         = qw/__ __x __n __nx __xn N__ N__n N__w/;
@@ -97,17 +98,17 @@ sub report($@)
     $opts->{location} ||= Log::Report::Dispatcher->collectLocation;
 
     my $exception;
-    if(UNIVERSAL::isa($message, 'Log::Report::Message'))
-    {   @_==0 or error __x"a message object is reported with more parameters";
+    if(!blessed $message)
+    {   # untranslated message into object
+        @_%2 and error __x"odd length parameter list with '{msg}'", msg => $message;
+        $message  = $lrm->new(_prepend => $message, @_);
     }
-    elsif(UNIVERSAL::isa($message, 'Log::Report::Exception'))
+    elsif($message->isa('Log::Report::Exception'))
     {   $exception = $message;
         $message   = $exception->message;
     }
-    else
-    {   # untranslated message into object
-        @_%2 and error __x"odd length parameter list with '{msg}'", msg => $message;
-        $message = Log::Report::Message->new(_prepend => $message, @_);
+    elsif($message->isa('Log::Report::Message'))
+    {   @_==0 or error __x"a message object is reported with more parameters";
     }
 
     if(my $to = $message->to)
@@ -280,7 +281,7 @@ sub panic(@)   {report PANIC   => @_}
 sub _default_domain(@) { pkg2domain $_[0] }
 
 sub __($)
-{   Log::Report::Message->new
+{   $lrm->new
       ( _msgid  => shift
       , _domain => _default_domain(caller)
       );
@@ -293,7 +294,7 @@ sub __x($@)
         where => join(' line ', (caller)[1,2]);
 
     my $msgid = shift;
-    Log::Report::Message->new
+    $lrm->new
      ( _msgid  => $msgid
      , _expand => 1
      , _domain => _default_domain(caller)
@@ -304,7 +305,7 @@ sub __x($@)
 
 sub __n($$$@)
 {   my ($single, $plural, $count) = (shift, shift, shift);
-    Log::Report::Message->new
+    $lrm->new
      ( _msgid  => $single
      , _plural => $plural
      , _count  => $count
@@ -316,7 +317,7 @@ sub __n($$$@)
 
 sub __nx($$$@)
 {   my ($single, $plural, $count) = (shift, shift, shift);
-    Log::Report::Message->new
+    $lrm->new
      ( _msgid  => $single
      , _plural => $plural
      , _count  => $count
@@ -329,7 +330,7 @@ sub __nx($$$@)
 
 sub __xn($$$@)   # repeated for prototype
 {   my ($single, $plural, $count) = (shift, shift, shift);
-    Log::Report::Message->new
+    $lrm->new
      ( _msgid  => $single
      , _plural => $plural
      , _count  => $count
@@ -399,6 +400,13 @@ sub import(@)
         }
     }
 
+    if(my $msg_class = delete $opts{message_class})
+    {   $msg_class->isa($lrm)
+            or error __x"message_class {class} does not extend {base}"
+                 , base => $lrm, class => $msg_class;
+        $lrm = $msg_class;
+    }
+
     $class->export_to_level(1+$to_level, undef, @export);
 
     ### Log::Report::Domain configuration
