@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.08';
 
 
 use Log::Report 'log-report';
@@ -191,7 +191,8 @@ sub translate($$$)
       = ( defined $format
         ? __x($format, message => $msg->toString , reason => $r, error => $e)
         : $msg
-        )->toString . "\n";
+        )->toString;
+    $text =~ s/\n*\z/\n/;
 
     if($show_loc)
     {   if(my $loc = $opts->{location} || $self->collectLocation)
