@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.01.
 package DieTests;
 use vars '$VERSION';
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 use warnings;
 use strict;
@@ -30,12 +30,14 @@ sub process($)
     my $stack = join "\n",
                     map { join '#', $_->[0], $_->[1], 'XX' }
                         @{$opt->{stack}};
-    <<__RESULT
+    my $r     = <<__RESULT;
 $reason: $message ($errno)
 $err
 $loca
 $stack
 __RESULT
+    $r =~ s!\\!/!g;   # Windows
+    $r;
 }
 
 sub run_tests()
